Class: GustoEmbedded::CompaniesSuspensions

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/gusto_embedded/companies_suspensions.rb

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ CompaniesSuspensions

Returns a new instance of CompaniesSuspensions.



17
18
19
# File 'lib/gusto_embedded/companies_suspensions.rb', line 17

def initialize(sdk_config)
  @sdk_configuration = sdk_config
end

Instance Method Details

#get(company_uuid, x_gusto_api_version = nil) ⇒ Object



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/gusto_embedded/companies_suspensions.rb', line 23

def get(company_uuid, x_gusto_api_version = nil)
  # get - Get suspensions for this company
  # Get existing suspension records for this company. A company may have multiple suspension records if they have suspended their Gusto account more than once. 
  # 
  # > 📘 To check if company is already suspended
  # >
  # > To determine if a company is _currently_ suspended, use the `is_suspended` and `company_status` fields in the [Get a company](https://docs.gusto.com/embedded-payroll/reference/get-v1-companies) endpoint.
  # 
  # scope: `company_suspensions:read`
  request = ::GustoEmbedded::Operations::GetCompaniesCompanyUuidSuspensionsRequest.new(
    
    company_uuid: company_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetCompaniesCompanyUuidSuspensionsRequest,
    base_url,
    '/v1/companies/{company_uuid}/suspensions',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetCompaniesCompanyUuidSuspensionsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::CompanySuspension])
      res.company_suspension_list = out
    end
  elsif r.status == 404
  end

  res
end

#suspend(company_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/gusto_embedded/companies_suspensions.rb', line 73

def suspend(company_uuid, request_body, x_gusto_api_version = nil)
  # suspend - Suspend a company's account
  # Use this endpoint to suspend a company. After suspension, company will no longer be able to run payroll but will retain access to their information, such as retrieving employee info or retrieving past payrolls.
  # 
  # scope: `company_suspensions:write`
  request = ::GustoEmbedded::Operations::PostCompaniesCompanyUuidSuspensionsRequest.new(
    
    company_uuid: company_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PostCompaniesCompanyUuidSuspensionsRequest,
    base_url,
    '/v1/companies/{company_uuid}/suspensions',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.post(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PostCompaniesCompanyUuidSuspensionsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::CompanySuspension)
      res.company_suspension = out
    end
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end