Class: GustoEmbedded::CompanyAttachment
- Inherits:
-
Object
- Object
- GustoEmbedded::CompanyAttachment
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/companyattachment.rb
Instance Method Summary collapse
- #get_download_url(company_id, company_attachment_uuid, x_gusto_api_version = nil) ⇒ Object
-
#initialize(sdk_config) ⇒ CompanyAttachment
constructor
A new instance of CompanyAttachment.
Constructor Details
#initialize(sdk_config) ⇒ CompanyAttachment
Returns a new instance of CompanyAttachment.
17 18 19 |
# File 'lib/gusto_embedded/companyattachment.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#get_download_url(company_id, company_attachment_uuid, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/gusto_embedded/companyattachment.rb', line 23 def get_download_url(company_id, , x_gusto_api_version = nil) # get_download_url - Get a temporary url to download the Company Attachment file # Retrieve a temporary url to download a attachment file uploaded # by the company. # # scope: `company_attachments:read` request = ::GustoEmbedded::Operations::GetV1CompaniesAttachmentUrlRequest.new( company_id: company_id, company_attachment_uuid: , x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1CompaniesAttachmentUrlRequest, base_url, '/v1/companies/{company_id}/attachments/{company_attachment_uuid}/download_url', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1CompaniesAttachmentUrlResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Operations::GetV1CompaniesAttachmentUrlResponseBody) res.object = out end elsif r.status == 404 end res end |