Class: GustoEmbedded::CompanyAttachments

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/gusto_embedded/companyattachments.rb

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ CompanyAttachments

Returns a new instance of CompanyAttachments.



17
18
19
# File 'lib/gusto_embedded/companyattachments.rb', line 17

def initialize(sdk_config)
  @sdk_configuration = sdk_config
end

Instance Method Details

#create(company_id, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/gusto_embedded/companyattachments.rb', line 116

def create(company_id, request_body, x_gusto_api_version = nil)
  # create - Create Company Attachment and Upload File
  # Upload a file and create a company attachment. We recommend uploading
  # PDF files for optimal compatibility. However, the following file types are
  # allowed: .qbb, .qbm, .gif, .jpg, .png, .pdf, .xls, .xlsx, .doc and .docx. 
  # 
  # scope: `company_attachments:write`
  request = ::GustoEmbedded::Operations::PostV1CompaniesAttachmentRequest.new(
    
    company_id: company_id,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PostV1CompaniesAttachmentRequest,
    base_url,
    '/v1/companies/{company_id}/attachments',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :multipart)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.post(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PostV1CompaniesAttachmentResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 201
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::CompanyAttachment)
      res.company_attachment = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#get_details(company_id, company_attachment_uuid, x_gusto_api_version = nil) ⇒ Object



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/gusto_embedded/companyattachments.rb', line 23

def get_details(company_id, company_attachment_uuid, x_gusto_api_version = nil)
  # get_details - Get Company Attachment Details
  # Retrieve the detail of an attachment uploaded by the company.
  # 
  # scope: `company_attachments:read`
  request = ::GustoEmbedded::Operations::GetV1CompaniesAttachmentRequest.new(
    
    company_id: company_id,
    company_attachment_uuid: company_attachment_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1CompaniesAttachmentRequest,
    base_url,
    '/v1/companies/{company_id}/attachments/{company_attachment_uuid}',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1CompaniesAttachmentResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::CompanyAttachment)
      res.company_attachment = out
    end
  elsif r.status == 404
  end

  res
end

#get_list(company_id, x_gusto_api_version = nil) ⇒ Object



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/gusto_embedded/companyattachments.rb', line 70

def get_list(company_id, x_gusto_api_version = nil)
  # get_list - Get List of Company Attachments
  # Retrieve a list of all the attachments uploaded by the company.
  # 
  # scope: `company_attachments:read`
  request = ::GustoEmbedded::Operations::GetV1CompaniesAttachmentsRequest.new(
    
    company_id: company_id,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1CompaniesAttachmentsRequest,
    base_url,
    '/v1/companies/{company_id}/attachments',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1CompaniesAttachmentsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::CompanyAttachment])
      res.company_attachment_list = out
    end
  elsif r.status == 404
  end

  res
end