Class: GustoEmbedded::ContractorPayments

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/gusto_embedded/contractorpayments.rb

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ ContractorPayments

Returns a new instance of ContractorPayments.



17
18
19
# File 'lib/gusto_embedded/contractorpayments.rb', line 17

def initialize(sdk_config)
  @sdk_configuration = sdk_config
end

Instance Method Details

#create(company_id, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/gusto_embedded/contractorpayments.rb', line 131

def create(company_id, request_body, x_gusto_api_version = nil)
  # create - Create a contractor payment
  # Pay a contractor. Information needed depends on the contractor's wage type (hourly vs fixed)
  # 
  # scope: `payrolls:run`
  request = ::GustoEmbedded::Operations::PostV1CompaniesCompanyIdContractorPaymentsRequest.new(
    
    company_id: company_id,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PostV1CompaniesCompanyIdContractorPaymentsRequest,
    base_url,
    '/v1/companies/{company_id}/contractor_payments',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.post(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PostV1CompaniesCompanyIdContractorPaymentsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::ContractorPayment)
      res.contractor_payment = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#delete(company_id, contractor_payment_id, x_gusto_api_version = nil) ⇒ Object



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/gusto_embedded/contractorpayments.rb', line 282

def delete(company_id, contractor_payment_id, x_gusto_api_version = nil)
  # delete - Cancel a contractor payment
  # Cancels and deletes a contractor payment. If the contractor payment has already started processing ("may_cancel": true), the payment cannot be cancelled.
  # 
  # scope: `payrolls:run`
  request = ::GustoEmbedded::Operations::DeleteV1CompaniesCompanyIdContractorPaymentContractorPaymentRequest.new(
    
    company_id: company_id,
    contractor_payment_id: contractor_payment_id,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::DeleteV1CompaniesCompanyIdContractorPaymentContractorPaymentRequest,
    base_url,
    '/v1/companies/{company_id}/contractor_payments/{contractor_payment_id}',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.delete(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::DeleteV1CompaniesCompanyIdContractorPaymentContractorPaymentResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 204
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#fund(contractor_payment_uuid, x_gusto_api_version = nil) ⇒ Object



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/gusto_embedded/contractorpayments.rb', line 76

def fund(contractor_payment_uuid, x_gusto_api_version = nil)
  # fund - Fund a contractor payment [DEMO]
  # > 🚧 Demo action
  # >
  # > This action is only available in the Demo environment
  # 
  # Simulate funding a contractor payment. Funding only occurs automatically in the production environment when bank transactions are generated. Use this action in the demo environment to transition a contractor payment's `status` from `Unfunded` to `Funded`. A `Funded` status is required for generating a contractor payment receipt.
  # 
  # scope: `payrolls:run`
  request = ::GustoEmbedded::Operations::GetV1ContractorPaymentsContractorPaymentUuidFundRequest.new(
    
    contractor_payment_uuid: contractor_payment_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1ContractorPaymentsContractorPaymentUuidFundRequest,
    base_url,
    '/v1/contractor_payments/{contractor_payment_uuid}/fund',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1ContractorPaymentsContractorPaymentUuidFundResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::ContractorPayment)
      res.contractor_payment = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#get(company_id, contractor_payment_id, x_gusto_api_version = nil) ⇒ Object



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/gusto_embedded/contractorpayments.rb', line 236

def get(company_id, contractor_payment_id, x_gusto_api_version = nil)
  # get - Get a single contractor payment
  # Returns a single contractor payment.
  # scope: `payrolls:read`
  request = ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdContractorPaymentContractorPaymentRequest.new(
    
    company_id: company_id,
    contractor_payment_id: contractor_payment_id,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdContractorPaymentContractorPaymentRequest,
    base_url,
    '/v1/companies/{company_id}/contractor_payments/{contractor_payment_id}',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdContractorPaymentContractorPaymentResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::ContractorPayment)
      res.contractor_payment = out
    end
  elsif r.status == 404
  end

  res
end

#get_receipt(contractor_payment_uuid, x_gusto_api_version = nil) ⇒ Object



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/gusto_embedded/contractorpayments.rb', line 23

def get_receipt(contractor_payment_uuid, x_gusto_api_version = nil)
  # get_receipt - Get a single contractor payment receipt
  # Returns a contractor payment receipt.
  # 
  # Notes:
  # * Receipts are only available for direct deposit payments and are only available once those payments have been funded.
  # * Payroll Receipt requests for payrolls which do not have receipts available (e.g. payment by check) will return a 404 status.
  # * Hour and dollar amounts are returned as string representations of numeric decimals.
  # * Dollar amounts are represented to the cent.
  # * If no data has yet be inserted for a given field, it defaults to “0.00” (for fixed amounts).
  # 
  # scope: `payrolls:read`
  request = ::GustoEmbedded::Operations::GetV1ContractorPaymentsContractorPaymentUuidReceiptRequest.new(
    
    contractor_payment_uuid: contractor_payment_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1ContractorPaymentsContractorPaymentUuidReceiptRequest,
    base_url,
    '/v1/contractor_payments/{contractor_payment_uuid}/receipt',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1ContractorPaymentsContractorPaymentUuidReceiptResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::ContractorPaymentReceipt)
      res.contractor_payment_receipt = out
    end
  elsif r.status == 404
  end

  res
end

#list(request) ⇒ Object



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/gusto_embedded/contractorpayments.rb', line 193

def list(request)
  # list - Get contractor payments for a company
  # Returns an object containing individual contractor payments, within a given time period, including totals.
  # 
  # scope: `payrolls:read`
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdContractorPaymentsRequest,
    base_url,
    '/v1/companies/{company_id}/contractor_payments',
    request
  )
  headers = Utils.get_headers(request)
  query_params = Utils.get_query_params(::GustoEmbedded::Operations::GetV1CompaniesCompanyIdContractorPaymentsRequest, request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    req.params = query_params
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdContractorPaymentsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::Object)
      res.one_of = out
    end
  elsif r.status == 404
  end

  res
end

#preview(company_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/gusto_embedded/contractorpayments.rb', line 330

def preview(company_uuid, request_body, x_gusto_api_version = nil)
  # preview - Preview contractor payment debit date
  # Returns a debit_date dependent on the ACH payment speed of the company.
  # 
  # If the payment method is Check or Historical payment, the debit_date will be the same as the check_date.
  # 
  # scope: `payrolls:read`
  request = ::GustoEmbedded::Operations::GetCompaniesCompanyUuidContractorPaymentsPreviewRequest.new(
    
    company_uuid: company_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetCompaniesCompanyUuidContractorPaymentsPreviewRequest,
    base_url,
    '/v1/companies/{company_uuid}/contractor_payments/preview',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetCompaniesCompanyUuidContractorPaymentsPreviewResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Operations::GetCompaniesCompanyUuidContractorPaymentsPreviewResponseBody)
      res.two_hundred_application_json_object = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Operations::GetCompaniesCompanyUuidContractorPaymentsPreviewContractorPaymentsResponseBody)
      res.four_hundred_and_twenty_two_application_json_object = out
    end
  end

  res
end