Class: GustoEmbedded::Contractors

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/gusto_embedded/contractors.rb

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ Contractors

Returns a new instance of Contractors.



17
18
19
# File 'lib/gusto_embedded/contractors.rb', line 17

def initialize(sdk_config)
  @sdk_configuration = sdk_config
end

Instance Method Details

#create(company_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/gusto_embedded/contractors.rb', line 23

def create(company_uuid, request_body, x_gusto_api_version = nil)
  # create - Create a contractor
  # Create an individual or business contractor.
  # 
  # scope: `contractors:manage`
  request = ::GustoEmbedded::Operations::PostV1CompaniesCompanyUuidContractorsRequest.new(
    
    company_uuid: company_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PostV1CompaniesCompanyUuidContractorsRequest,
    base_url,
    '/v1/companies/{company_uuid}/contractors',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.post(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PostV1CompaniesCompanyUuidContractorsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 201
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Contractor)
      res.contractor = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#delete(contractor_uuid, x_gusto_api_version = nil) ⇒ Object



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/gusto_embedded/contractors.rb', line 240

def delete(contractor_uuid, x_gusto_api_version = nil)
  # delete - Delete a contractor
  # A contractor can only be deleted when there are no contractor payments.
  # 
  # scope: `contractors:manage`
  request = ::GustoEmbedded::Operations::DeleteV1ContractorsContractorUuidRequest.new(
    
    contractor_uuid: contractor_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::DeleteV1ContractorsContractorUuidRequest,
    base_url,
    '/v1/contractors/{contractor_uuid}',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = '*/*'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.delete(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::DeleteV1ContractorsContractorUuidResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 204
  elsif r.status == 404
  end

  res
end

#get(contractor_uuid, x_gusto_api_version = nil) ⇒ Object



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/gusto_embedded/contractors.rb', line 128

def get(contractor_uuid, x_gusto_api_version = nil)
  # get - Get a contractor
  # Get a contractor.
  # 
  # scope: `contractors:read`
  request = ::GustoEmbedded::Operations::GetV1ContractorsContractorUuidRequest.new(
    
    contractor_uuid: contractor_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1ContractorsContractorUuidRequest,
    base_url,
    '/v1/contractors/{contractor_uuid}',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1ContractorsContractorUuidResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Contractor)
      res.contractor = out
    end
  elsif r.status == 404
  end

  res
end

#get_address(contractor_uuid, x_gusto_api_version = nil) ⇒ Object



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/gusto_embedded/contractors.rb', line 431

def get_address(contractor_uuid, x_gusto_api_version = nil)
  # get_address - Get a contractor address
  # The address of a contractor is used to determine certain tax information about them. Addresses are geocoded on create and update to ensure validity.
  # 
  # scope: `contractors:read`
  request = ::GustoEmbedded::Operations::GetV1ContractorsContractorUuidAddressRequest.new(
    
    contractor_uuid: contractor_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1ContractorsContractorUuidAddressRequest,
    base_url,
    '/v1/contractors/{contractor_uuid}/address',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1ContractorsContractorUuidAddressResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::ContractorAddress)
      res.contractor_address = out
    end
  elsif r.status == 404
  end

  res
end

#get_onboarding_status(contractor_uuid, x_gusto_api_version = nil) ⇒ Object



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/gusto_embedded/contractors.rb', line 282

def get_onboarding_status(contractor_uuid, x_gusto_api_version = nil)
  # get_onboarding_status - Get the contractor's onboarding status
  # Retrieves a contractor's onboarding status. The data returned helps inform the required onboarding steps and respective completion status.
  # 
  # scope: `contractors:read`
  # 
  # ## onboarding_status
  # 
  # ### Admin-facilitated onboarding
  # | onboarding_status | Description |
  # |:------------------|------------:|
  # | `admin_onboarding_incomplete` | Admin needs to enter basic information about the contractor. |
  # | `admin_onboarding_review` | All information has been completed and admin needs to confirm onboarding. |
  # | `onboarding_completed` | Contractor has been fully onboarded and verified. |
  # 
  # ### Contractor self-onboarding
  # 
  # | onboarding_status | Description |
  # | --- | ----------- |
  # | `admin_onboarding_incomplete` | Admin needs to enter basic information about the contractor. |
  # | `self_onboarding_not_invited` | Admin has the intention to invite the contractor to self-onboard (e.g., marking a checkbox), but the system has not yet sent the invitation. |
  # | `self_onboarding_invited` | Contractor has been sent an invitation to self-onboard. |
  # | `self_onboarding_started` | Contractor has started the self-onboarding process. |
  # | `self_onboarding_review` | Admin needs to review contractors's entered information and confirm onboarding. |
  # | `onboarding_completed` | Contractor has been fully onboarded and verified. |
  # 
  # ## onboarding_steps
  # 
  # | onboarding_steps | Requirement(s) to be completed |
  # |:-----------------|-------------------------------:|
  # | `basic_details` | Add individual contractor's first name, last name, social security number or Business name and EIN depending on the contractor type |
  # | `add_address` | Add contractor address. |
  # | `compensation_details` | Add contractor compensation. |
  # | `payment_details` | Set up contractor's direct deposit or set to check. |
  # | `sign_documents` | Contractor forms (e.g., W9) are generated & signed. |
  # | `file_new_hire_report` | Contractor new hire report is generated. |
  request = ::GustoEmbedded::Operations::GetV1ContractorsContractorUuidOnboardingStatusRequest.new(
    
    contractor_uuid: contractor_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1ContractorsContractorUuidOnboardingStatusRequest,
    base_url,
    '/v1/contractors/{contractor_uuid}/onboarding_status',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1ContractorsContractorUuidOnboardingStatusResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::ContractorOnboardingStatus)
      res.contractor_onboarding_status = out
    end
  elsif r.status == 404
  end

  res
end

#list(request) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/gusto_embedded/contractors.rb', line 85

def list(request)
  # list - Get contractors of a company
  # Get all contractors, active and inactive, individual and business, for a company.
  # 
  # scope: `contractors:read`
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1CompaniesCompanyUuidContractorsRequest,
    base_url,
    '/v1/companies/{company_uuid}/contractors',
    request
  )
  headers = Utils.get_headers(request)
  query_params = Utils.get_query_params(::GustoEmbedded::Operations::GetV1CompaniesCompanyUuidContractorsRequest, request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    req.params = query_params
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1CompaniesCompanyUuidContractorsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::Contractor])
      res.contractor_list = out
    end
  elsif r.status == 404
  end

  res
end

#update(contractor_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/gusto_embedded/contractors.rb', line 174

def update(contractor_uuid, request_body, x_gusto_api_version = nil)
  # update - Update a contractor
  # Update a contractor.
  # 
  # scope: `contractors:write`
  # 
  # > 🚧 Warning
  # >
  # > Watch out when changing a contractor's type (when the contractor is finished onboarding). Specifically, changing contractor type can be dangerous since Gusto won’t recognize and file two separate 1099s if they simply change from business to individual
  request = ::GustoEmbedded::Operations::PutV1ContractorsContractorUuidRequest.new(
    
    contractor_uuid: contractor_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PutV1ContractorsContractorUuidRequest,
    base_url,
    '/v1/contractors/{contractor_uuid}',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PutV1ContractorsContractorUuidResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Contractor)
      res.contractor = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#update_address(contractor_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
# File 'lib/gusto_embedded/contractors.rb', line 477

def update_address(contractor_uuid, request_body, x_gusto_api_version = nil)
  # update_address - Update a contractor's address
  # The address of a contractor is used to determine certain tax information about them. Addresses are geocoded on create and update to ensure validity.
  # 
  # scope: `contractors:write`
  request = ::GustoEmbedded::Operations::PutV1ContractorsContractorUuidAddressRequest.new(
    
    contractor_uuid: contractor_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PutV1ContractorsContractorUuidAddressRequest,
    base_url,
    '/v1/contractors/{contractor_uuid}/address',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PutV1ContractorsContractorUuidAddressResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::ContractorAddress)
      res.contractor_address = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#update_onboarding_status(contractor_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/gusto_embedded/contractors.rb', line 359

def update_onboarding_status(contractor_uuid, request_body, x_gusto_api_version = nil)
  # update_onboarding_status - Change the contractor's onboarding status
  # Updates a contractor's onboarding status.
  # 
  # scope: `contractors:write`
  # 
  # Below is a list of valid onboarding status changes depending on the intended action to be performed on behalf of the contractor.
  # 
  # | Action | current onboarding_status | new onboarding_status |
  # |:------------------|:------------:|----------:|
  # | Mark a contractor as self-onboarding | `admin_onboarding_incomplete` | `self_onboarding_not_invited` |
  # | Invite a contractor to self-onboard | `admin_onboarding_incomplete` or `self_onboarding_not_invited` | `self_onboarding_invited` |
  # | Cancel a contractor's self-onboarding | `self_onboarding_invited` or `self_onboarding_not_invited` | `admin_onboarding_incomplete` |
  # | Review a contractor's self-onboarded info | `self_onboarding_started` | `self_onboarding_review` |
  # | Finish a contractor's onboarding | `admin_onboarding_review` or `self_onboarding_review` | `onboarding_completed` |
  request = ::GustoEmbedded::Operations::PutV1ContractorsContractorUuidOnboardingStatusRequest.new(
    
    contractor_uuid: contractor_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PutV1ContractorsContractorUuidOnboardingStatusRequest,
    base_url,
    '/v1/contractors/{contractor_uuid}/onboarding_status',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PutV1ContractorsContractorUuidOnboardingStatusResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::ContractorOnboardingStatus)
      res.contractor_onboarding_status = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end