Class: GustoEmbedded::Departments

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/gusto_embedded/departments.rb

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ Departments

Returns a new instance of Departments.



17
18
19
# File 'lib/gusto_embedded/departments.rb', line 17

def initialize(sdk_config)
  @sdk_configuration = sdk_config
end

Instance Method Details

#add_people(department_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/gusto_embedded/departments.rb', line 288

def add_people(department_uuid, request_body, x_gusto_api_version = nil)
  # add_people - Add people to a department
  # Add employees and contractors to a department
  # 
  # scope: `departments:write`
  # 
  request = ::GustoEmbedded::Operations::PutAddPeopleToDepartmentRequest.new(
    
    department_uuid: department_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PutAddPeopleToDepartmentRequest,
    base_url,
    '/v1/departments/{department_uuid}/add',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PutAddPeopleToDepartmentResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Department)
      res.department = out
    end
  elsif r.status == 404
  end

  res
end

#create(company_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/gusto_embedded/departments.rb', line 23

def create(company_uuid, request_body, x_gusto_api_version = nil)
  # create - Create a department
  # Create a department
  # 
  # scope: `departments:write`
  request = ::GustoEmbedded::Operations::PostDepartmentsRequest.new(
    
    company_uuid: company_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PostDepartmentsRequest,
    base_url,
    '/v1/companies/{company_uuid}/departments',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.post(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PostDepartmentsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 201
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Department)
      res.department = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#delete(department_uuid, x_gusto_api_version = nil) ⇒ Object



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/gusto_embedded/departments.rb', line 240

def delete(department_uuid, x_gusto_api_version = nil)
  # delete - Delete a department
  # Delete a department. You cannot delete a department until all employees and contractors have been removed.
  # 
  # scope: `departments:write`
  # 
  request = ::GustoEmbedded::Operations::DeleteDepartmentRequest.new(
    
    department_uuid: department_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::DeleteDepartmentRequest,
    base_url,
    '/v1/departments/{department_uuid}',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.delete(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::DeleteDepartmentResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 204
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#get(department_uuid, x_gusto_api_version = nil) ⇒ Object



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/gusto_embedded/departments.rb', line 131

def get(department_uuid, x_gusto_api_version = nil)
  # get - Get a department
  # Get a department given the UUID
  # 
  # scope: `departments:read`
  # 
  request = ::GustoEmbedded::Operations::GetDepartmentRequest.new(
    
    department_uuid: department_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetDepartmentRequest,
    base_url,
    '/v1/departments/{department_uuid}',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetDepartmentResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Department)
      res.department = out
    end
  elsif r.status == 404
  end

  res
end

#get_all(company_uuid, x_gusto_api_version = nil) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/gusto_embedded/departments.rb', line 85

def get_all(company_uuid, x_gusto_api_version = nil)
  # get_all - Get all departments of a company
  # Get all of the departments for a given company with the employees and contractors assigned to that department.
  # 
  # scope: `departments:read`
  request = ::GustoEmbedded::Operations::GetCompaniesDepartmentsRequest.new(
    
    company_uuid: company_uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetCompaniesDepartmentsRequest,
    base_url,
    '/v1/companies/{company_uuid}/departments',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetCompaniesDepartmentsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::Department])
      res.department_list = out
    end
  elsif r.status == 404
  end

  res
end

#remove_people(department_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/gusto_embedded/departments.rb', line 346

def remove_people(department_uuid, request_body, x_gusto_api_version = nil)
  # remove_people - Remove people from a department
  # Remove employees and contractors from a department
  # 
  # scope: `departments:write`
  # 
  request = ::GustoEmbedded::Operations::PutRemovePeopleFromDepartmentRequest.new(
    
    department_uuid: department_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PutRemovePeopleFromDepartmentRequest,
    base_url,
    '/v1/departments/{department_uuid}/remove',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PutRemovePeopleFromDepartmentResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Department)
      res.department = out
    end
  elsif r.status == 404
  end

  res
end

#update(department_uuid, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/gusto_embedded/departments.rb', line 178

def update(department_uuid, request_body, x_gusto_api_version = nil)
  # update - Update a department
  # Update a department
  # 
  # scope: `departments:write`
  request = ::GustoEmbedded::Operations::PutDepartmentsRequest.new(
    
    department_uuid: department_uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PutDepartmentsRequest,
    base_url,
    '/v1/departments/{department_uuid}',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PutDepartmentsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Department)
      res.department = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end