Class: GustoEmbedded::I9Verification

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/gusto_embedded/i9verification.rb

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ I9Verification

Returns a new instance of I9Verification.



17
18
19
# File 'lib/gusto_embedded/i9verification.rb', line 17

def initialize(sdk_config)
  @sdk_configuration = sdk_config
end

Instance Method Details

#create_documents(employee_id, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/gusto_embedded/i9verification.rb', line 243

def create_documents(employee_id, request_body, x_gusto_api_version = nil)
  # create_documents - Create an employee's I-9 authorization verification documents
  # An employee's I-9 verification documents are the documents an employee has provided the employer to verify their identity and authorization to work in the United States.
  # 
  # Use the document options endpoint to get the possible document types and titles, which can vary depending on the employee's authorization status.
  # 
  # > 🚧 Every request must contain the complete list of documents for the Employee.
  # >
  # > Every request to this endpoint removes any previous verification document records for the employee.
  # 
  # scope: `i9_authorizations:manage`
  # 
  request = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdI9AuthorizationDocumentsRequest.new(
    
    employee_id: employee_id,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdI9AuthorizationDocumentsRequest,
    base_url,
    '/v1/employees/{employee_id}/i9_authorization/documents',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdI9AuthorizationDocumentsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::I9AuthorizationDocument])
      res.i9_authorization_documents_object = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#delete_document(employee_id, document_id, x_gusto_api_version = nil) ⇒ Object



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/gusto_embedded/i9verification.rb', line 312

def delete_document(employee_id, document_id, x_gusto_api_version = nil)
  # delete_document - Delete an employee's I-9 verification document
  # An employee's I-9 verification documents are the documents an employee has provided the employer to verify their identity and authorization to work in the United States. This endpoint deletes a specific verification document.
  # 
  # scope: `i9_authorizations:manage`
  request = ::GustoEmbedded::Operations::DeleteV1EmployeesEmployeeIdI9AuthorizationDocumentsDocumentIdRequest.new(
    
    employee_id: employee_id,
    document_id: document_id,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::DeleteV1EmployeesEmployeeIdI9AuthorizationDocumentsDocumentIdRequest,
    base_url,
    '/v1/employees/{employee_id}/i9_authorization/documents/{document_id}',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = '*/*'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.delete(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::DeleteV1EmployeesEmployeeIdI9AuthorizationDocumentsDocumentIdResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 204
  elsif r.status == 404
  end

  res
end

#employer_sign(employee_id, request_body, x_gusto_client_ip = nil, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/gusto_embedded/i9verification.rb', line 355

def employer_sign(employee_id, request_body, x_gusto_client_ip = nil, x_gusto_api_version = nil)
  # employer_sign - Employer sign an employee's Form I-9
  # Sign an employee's Form I-9 as an employer. Once the form is signed, the employee's I-9 authorization is considered complete and cannot be modified.
  # 
  # scope: `i9_authorizations:manage`
  request = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdI9AuthorizationEmployerSignRequest.new(
    
    employee_id: employee_id,
    request_body: request_body,
    x_gusto_client_ip: x_gusto_client_ip,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdI9AuthorizationEmployerSignRequest,
    base_url,
    '/v1/employees/{employee_id}/i9_authorization/employer_sign',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdI9AuthorizationEmployerSignResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::I9Authorization)
      res.i9_authorization = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end

#get_authorization(employee_id, x_gusto_api_version = nil) ⇒ Object



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/gusto_embedded/i9verification.rb', line 23

def get_authorization(employee_id, x_gusto_api_version = nil)
  # get_authorization - Get an employee's I-9 authorization
  # An employee's I-9 authorization stores information about an employee's authorization status and I-9 signatures, information required to filled out the Form I-9 for employment eligibility verification.
  # 
  # **NOTE:** The `form_uuid` in responses from this endpoint can be used to retrieve the PDF version of the I-9. See the "get employee form PDF" request for more details.
  # 
  # scope: `i9_authorizations:read`
  request = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdI9AuthorizationRequest.new(
    
    employee_id: employee_id,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdI9AuthorizationRequest,
    base_url,
    '/v1/employees/{employee_id}/i9_authorization',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdI9AuthorizationResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::I9Authorization)
      res.i9_authorization = out
    end
  elsif r.status == 404
  end

  res
end

#get_document_options(employee_id, x_gusto_api_version = nil) ⇒ Object



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/gusto_embedded/i9verification.rb', line 151

def get_document_options(employee_id, x_gusto_api_version = nil)
  # get_document_options - Get an employee's I-9 verification document options
  # An employee's I-9 verification documents are the documents an employee has provided the employer to verify their identity and authorization to work in the United States. This endpoint returns the possible document options based on the employee's authorization status. These options can then be used to create the I-9 verification documents.
  # 
  # scope: `i9_authorizations:read`
  request = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdI9AuthorizationDocumentOptionsRequest.new(
    
    employee_id: employee_id,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdI9AuthorizationDocumentOptionsRequest,
    base_url,
    '/v1/employees/{employee_id}/i9_authorization/document_options',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdI9AuthorizationDocumentOptionsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::I9AuthorizationDocumentOption])
      res.i9_authorization_document_options_object = out
    end
  elsif r.status == 404
  end

  res
end

#get_documents(employee_id, x_gusto_api_version = nil) ⇒ Object



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/gusto_embedded/i9verification.rb', line 197

def get_documents(employee_id, x_gusto_api_version = nil)
  # get_documents - Get an employee's I-9 verification documents
  # An employee's I-9 verification documents are the documents an employee has provided the employer to verify their identity and authorization to work in the United States.
  # 
  # scope: `i9_authorizations:read`
  request = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdI9AuthorizationDocumentsRequest.new(
    
    employee_id: employee_id,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdI9AuthorizationDocumentsRequest,
    base_url,
    '/v1/employees/{employee_id}/i9_authorization/documents',
    request
  )
  headers = Utils.get_headers(request)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdI9AuthorizationDocumentsResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::I9AuthorizationDocument])
      res.i9_authorization_documents_object = out
    end
  elsif r.status == 404
  end

  res
end

#update(employee_id, request_body, x_gusto_api_version = nil) ⇒ Object

Raises:

  • (StandardError)


71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/gusto_embedded/i9verification.rb', line 71

def update(employee_id, request_body, x_gusto_api_version = nil)
  # update - Create or update an employee's I-9 authorization
  # An employee's I-9 authorization stores information about an employee's authorization status, as well as signatures and other information required to complete the Form I-9 for employment eligibility verification.
  # 
  # If the version is supplied and the employee I-9 authorization exists, this endpoint acts as an update. Otherwise, it will create an employee I-9 authorization.
  # 
  # Validations on this endpoint are conditional:
  # 
  #   * `document_type` may be required, depending on `authorization_status`.
  #   * Valid formats for `document_number` vary, depending on `document_type`.
  #   * `country` is only allowed with `document_type: 'foreign_passport'`.
  #   * `expiration_date` is only allowed with `authorization_status: 'alien'`.
  # 
  # > ℹ️ Unneeded information is automatically removed during updates.
  # >
  # > If an update causes some formerly-required fields to be unneeded, the now-unneeded data will be removed automatically.
  # >
  # > **Example:** Updating `authorization_status` from `alien` to `citizen` will cause any data in `document_type`, `document_number`, `country`, and `expiration_date` to be removed, since these fields are unused for `authorization_status:'citizen'`.
  # 
  # Detailed instructions for completing Form I-9 can be found at https://www.uscis.gov/sites/default/files/document/forms/i-9instr.pdf
  # 
  # scope: `i9_authorizations:write`
  # 
  request = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdI9AuthorizationRequest.new(
    
    employee_id: employee_id,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdI9AuthorizationRequest,
    base_url,
    '/v1/employees/{employee_id}/i9_authorization',
    request
  )
  headers = Utils.get_headers(request)
  req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.put(url) do |req|
    req.headers = headers
    security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil
    Utils.configure_request_security(req, security) if !security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdI9AuthorizationResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::I9Authorization)
      res.i9_authorization = out
    end
  elsif r.status == 404
  elsif r.status == 422
    if Utils.match_content_type(content_type, 'application/json')
      out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject)
      res.unprocessable_entity_error_object = out
    end
  end

  res
end