Class: GustoEmbedded::Models::Shared::BLSOccupation

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/gusto_embedded/models/shared/bls_occupation.rb

Overview

A Bureau of Labor Statistics occupation code with its title and description, used for salary estimate calculations.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(code:, title:, description: nil) ⇒ BLSOccupation

Returns a new instance of BLSOccupation.



23
24
25
26
27
# File 'lib/gusto_embedded/models/shared/bls_occupation.rb', line 23

def initialize(code:, title:, description: nil)
  @code = code
  @title = title
  @description = description
end

Instance Method Details

#==(other) ⇒ Object



30
31
32
33
34
35
36
# File 'lib/gusto_embedded/models/shared/bls_occupation.rb', line 30

def ==(other)
  return false unless other.is_a? self.class
  return false unless @code == other.code
  return false unless @title == other.title
  return false unless @description == other.description
  true
end