Class: GustoEmbedded::Models::Shared::ChildSupportDataKey
- Inherits:
-
T::Enum
- Object
- T::Enum
- GustoEmbedded::Models::Shared::ChildSupportDataKey
- Defined in:
- lib/gusto_embedded/models/shared/child_support_data_key.rb
Overview
ChildSupportDataKey - A required attribute when creating a garnishment for this state agency. The current values are listed as an enum; though unlikely, values could be added if state agency requirements change in the future.