Class: GustoEmbedded::Models::Shared::ContractorPaymentSummaryByDates

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/gusto_embedded/models/shared/contractor_payment_summary_by_dates.rb

Overview

The representation of the summary of contractor payments for a given company in a given time period.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(total: nil, contractor_payments: nil) ⇒ ContractorPaymentSummaryByDates

Returns a new instance of ContractorPaymentSummaryByDates.



21
22
23
24
# File 'lib/gusto_embedded/models/shared/contractor_payment_summary_by_dates.rb', line 21

def initialize(total: nil, contractor_payments: nil)
  @total = total
  @contractor_payments = contractor_payments
end

Instance Method Details

#==(other) ⇒ Object



27
28
29
30
31
32
# File 'lib/gusto_embedded/models/shared/contractor_payment_summary_by_dates.rb', line 27

def ==(other)
  return false unless other.is_a? self.class
  return false unless @total == other.total
  return false unless @contractor_payments == other.contractor_payments
  true
end