Class: GustoEmbedded::Models::Shared::ContractorPaymentsPreviewBody

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/gusto_embedded/models/shared/contractor_payments_preview_body.rb

Overview

Request body for previewing contractor payments. The expected debit date for the payments is calculated from the provided check date and the company’s ACH speed.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(contractor_payments:) ⇒ ContractorPaymentsPreviewBody

Returns a new instance of ContractorPaymentsPreviewBody.



19
20
21
# File 'lib/gusto_embedded/models/shared/contractor_payments_preview_body.rb', line 19

def initialize(contractor_payments:)
  @contractor_payments = contractor_payments
end

Instance Method Details

#==(other) ⇒ Object



24
25
26
27
28
# File 'lib/gusto_embedded/models/shared/contractor_payments_preview_body.rb', line 24

def ==(other)
  return false unless other.is_a? self.class
  return false unless @contractor_payments == other.contractor_payments
  true
end