Class: GustoEmbedded::Models::Shared::ExternalPayrollStatus

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/gusto_embedded/models/shared/external_payroll_status.rb

Overview

ExternalPayrollStatus - The status of the external payroll. The status will be ‘unprocessed` when the external payroll is created and transition to `processed` once tax liabilities are entered and finalized. Once in the `processed` status all actions that can edit an external payroll will be disabled.