Class: GustoEmbedded::Models::Shared::FederalTaxDetailsStatus

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/gusto_embedded/models/shared/federal_tax_details_status.rb

Overview

FederalTaxDetailsStatus - The status of EIN verification:

  • ‘pending`: The EIN verification process has not completed (or the company does not yet have an EIN).

  • ‘verified`: The EIN has been successfully verified as a valid EIN with the IRS.

  • ‘failed`: The company’s EIN did not pass verification. Common issues are being entered incorrectly or not matching the company’s legal name.