Class: GustoEmbedded::Models::Shared::LimitOption
- Inherits:
-
Object
- Object
- GustoEmbedded::Models::Shared::LimitOption
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/gusto_embedded/models/shared/limit_option.rb
Overview
Some benefits require additional information to determine their limit. For example, for an HSA benefit, the limit option should be either ‘Family’ or ‘Individual’. For a Dependent Care FSA benefit, the limit option should be either ‘Joint Filing or Single’ or ‘Married and Filing Separately’.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(required: nil, editable: nil, default_value: nil, choices: nil) ⇒ LimitOption
constructor
A new instance of LimitOption.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(required: nil, editable: nil, default_value: nil, choices: nil) ⇒ LimitOption
Returns a new instance of LimitOption.
25 26 27 28 29 30 |
# File 'lib/gusto_embedded/models/shared/limit_option.rb', line 25 def initialize(required: nil, editable: nil, default_value: nil, choices: nil) @required = required @editable = editable @default_value = default_value @choices = choices end |
Instance Method Details
#==(other) ⇒ Object
33 34 35 36 37 38 39 40 |
# File 'lib/gusto_embedded/models/shared/limit_option.rb', line 33 def ==(other) return false unless other.is_a? self.class return false unless @required == other.required return false unless @editable == other.editable return false unless @default_value == other.default_value return false unless @choices == other.choices true end |