Class: GustoEmbedded::Models::Shared::Status

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/gusto_embedded/models/shared/status.rb

Overview

Status - The status of the external payroll. The status will be ‘unprocessed` when the external payroll is created and transition to `processed` once tax liabilities are entered and finalized. Once in the `processed` status all actions that can edit an external payroll will be disabled.