Class: GustoEmbedded::Operations::DocumentType

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/gusto_embedded/models/operations/document_type.rb

Overview

DocumentType - The type of document an employee holds, based on their authorization status.

* This is unused for authorization status `citizen` or `noncitizen`.
* If the authorization status is `permanent_resident`, this must be `uscis_alien_registration_number`.
* If the authorization status is `alien`, this is required and may be any of the valid values.