Class: GustoEmbedded::Operations::EntityType

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/gusto_embedded/models/operations/entity_type.rb

Overview

EntityType - the type of target entity applicable to the flow. This field is optional for company flows, please refer to the flow_types table above for more details.