Class: GustoEmbedded::RecoveryCases
- Inherits:
-
Object
- Object
- GustoEmbedded::RecoveryCases
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/recoverycases.rb
Instance Method Summary collapse
- #get(company_uuid:, x_gusto_api_version: nil, page: nil, per: nil, timeout_ms: nil, http_headers: nil) ⇒ Object
- #get_url(base_url:, url_variables: nil) ⇒ Object
-
#initialize(sdk_config) ⇒ RecoveryCases
constructor
A new instance of RecoveryCases.
- #redebit(recovery_case_uuid:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ RecoveryCases
Returns a new instance of RecoveryCases.
21 22 23 24 |
# File 'lib/gusto_embedded/recoverycases.rb', line 21 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#get(company_uuid:, x_gusto_api_version: nil, page: nil, per: nil, timeout_ms: nil, http_headers: nil) ⇒ Object
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/gusto_embedded/recoverycases.rb', line 45 def get(company_uuid:, x_gusto_api_version: nil, page: nil, per: nil, timeout_ms: nil, http_headers: nil) # get - Get all recovery cases for a company # Fetch all recovery cases for a company. # # scope: `recovery_cases:read` # # If set, this operation will use `company_access_auth` from the global security. request = Models::Operations::GetRecoveryCasesRequest.new( company_uuid: company_uuid, x_gusto_api_version: x_gusto_api_version, page: page, per: per ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::GetRecoveryCasesRequest, base_url, '/v1/companies/{company_uuid}/recovery_cases', request ) headers = Utils.get_headers(request) headers = T.cast(headers, T::Hash[String, String]) query_params = Utils.get_query_params(Models::Operations::GetRecoveryCasesRequest, request, nil) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'get-recovery-cases', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).get(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? req.params = query_params Utils.configure_request_security(req, security, %i[company_access_auth]) http_headers&.each do |key, value| req.headers[key.to_s] = value end @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise 'no response' end end content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream') if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Crystalline::Array.new(Models::Shared::RecoveryCase)) response = Models::Operations::GetRecoveryCasesResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, recovery_cases: T.unsafe(obj) ) return response else raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['404']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::NotFoundErrorObject) raise obj else raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' else raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown status code received' end end |
#get_url(base_url:, url_variables: nil) ⇒ Object
27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/gusto_embedded/recoverycases.rb', line 27 def get_url(base_url:, url_variables: nil) sd_base_url, = @sdk_configuration.get_server_details if base_url.nil? base_url = sd_base_url end if url_variables.nil? url_variables = end return Utils.template_url base_url, url_variables end |
#redebit(recovery_case_uuid:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil) ⇒ Object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/gusto_embedded/recoverycases.rb', line 183 def redebit(recovery_case_uuid:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil) # redebit - Initiate a redebit for a recovery case # After resolving the underlying bank error, initiate a redebit for an open recovery case. This submission is asynchronous and a successful request responds with a 202 HTTP status. # # It may take up to four business days for the ACH debit to process; in the meantime, the status of the recovery case will be in the `initiated_redebit` state. When funds are successfully redebited, the recovery case is transitioned to the `recovered` state. # # If the company has exceeded maximum redebit attempts, or if the recovery case is not in a redebitable state, the response will be 422 Unprocessable Entity. # # scope: `recovery_cases:write` # # If set, this operation will use `company_access_auth` from the global security. request = Models::Operations::RedebitRecoveryCaseRequest.new( recovery_case_uuid: recovery_case_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::RedebitRecoveryCaseRequest, base_url, '/v1/recovery_cases/{recovery_case_uuid}/redebit', request ) headers = Utils.get_headers(request) headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'redebit-recovery-case', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).put(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security, %i[company_access_auth]) http_headers&.each do |key, value| req.headers[key.to_s] = value end @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise 'no response' end end content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream') if Utils.match_status_code(http_response.status, ['202']) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) return Models::Operations::RedebitRecoveryCaseResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response ) elsif Utils.match_status_code(http_response.status, ['404']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::NotFoundErrorObject) raise obj else raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['422']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::UnprocessableEntityError) raise obj else raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' else raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown status code received' end end |