Class: GustoEmbedded::SalaryEstimates

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/gusto_embedded/salary_estimates.rb

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ SalaryEstimates

Returns a new instance of SalaryEstimates.



21
22
23
24
# File 'lib/gusto_embedded/salary_estimates.rb', line 21

def initialize(sdk_config)
  @sdk_configuration = sdk_config
  
end

Instance Method Details

#get_url(base_url:, url_variables: nil) ⇒ Object



27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/gusto_embedded/salary_estimates.rb', line 27

def get_url(base_url:, url_variables: nil)
  sd_base_url, sd_options = @sdk_configuration.get_server_details

  if base_url.nil?
    base_url = sd_base_url
  end

  if url_variables.nil?
    url_variables = sd_options
  end

  return Utils.template_url base_url, url_variables
end

#get_v1_salary_estimates_id(uuid:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil) ⇒ Object



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/gusto_embedded/salary_estimates.rb', line 213

def get_v1_salary_estimates_id(uuid:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil)
  # get_v1_salary_estimates_id - Get a salary estimate
  # Retrieve a salary estimate by its UUID. Returns the estimated salary calculation along with all occupation details, revenue, and location information.
  #
  # scope: `salary_estimates:read`
  #
  # If set, this operation will use `company_access_auth` from the global security.
  request = Models::Operations::GetV1SalaryEstimatesIdRequest.new(
    uuid: uuid,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    Models::Operations::GetV1SalaryEstimatesIdRequest,
    base_url,
    '/v1/salary_estimates/{uuid}',
    request
  )
  headers = Utils.get_headers(request)
  headers = T.cast(headers, T::Hash[String, String])
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'get-v1-salary_estimates-id',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).get(url) do |req|
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      Utils.configure_request_security(req, security, %i[company_access_auth])
      http_headers&.each do |key, value|
        req.headers[key.to_s] = value
      end

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    if http_response.nil? || Utils.error_status?(http_response.status)
      http_response = @sdk_configuration.hooks.after_error(
        error: error,
        hook_ctx: SDKHooks::AfterErrorHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    else
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    end
    
    if http_response.nil?
      raise error if !error.nil?
      raise 'no response'
    end
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['200'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Shared::SalaryEstimate)
      response = Models::Operations::GetV1SalaryEstimatesIdResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        salary_estimate: T.unsafe(obj)
      )

      return response
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['404'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::NotFoundErrorObject)
      raise obj
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  else
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown status code received'

  end
end

#get_v1_salary_estimates_occupations(security:, search:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil) ⇒ Object



673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
# File 'lib/gusto_embedded/salary_estimates.rb', line 673

def get_v1_salary_estimates_occupations(security:, search:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil)
  # get_v1_salary_estimates_occupations - Search for BLS occupations
  # Search for Bureau of Labor Statistics (BLS) occupations by name or keyword. This endpoint helps users find the appropriate occupation codes to use when creating or updating salary estimates.
  #
  # Returns a list of matching occupations with their codes, titles, and descriptions.
  #
  # 📘 System Access Authentication
  #
  # This endpoint uses the [Bearer Auth scheme with the system-level access token in the HTTP Authorization header](https://docs.gusto.com/embedded-payroll/docs/system-access)
  #
  # scope: `salary_estimates:read`
  request = Models::Operations::GetV1SalaryEstimatesOccupationsRequest.new(
    search: search,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = "#{base_url}/v1/salary_estimates/occupations"
  headers = Utils.get_headers(request)
  headers = T.cast(headers, T::Hash[String, String])
  query_params = Utils.get_query_params(Models::Operations::GetV1SalaryEstimatesOccupationsRequest, request, nil)
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'get-v1-salary_estimates-occupations',
    security_source: -> { security }
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).get(url) do |req|
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      req.params = query_params
      Utils.configure_request_security(req, security)
      http_headers&.each do |key, value|
        req.headers[key.to_s] = value
      end

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    if http_response.nil? || Utils.error_status?(http_response.status)
      http_response = @sdk_configuration.hooks.after_error(
        error: error,
        hook_ctx: SDKHooks::AfterErrorHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    else
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    end
    
    if http_response.nil?
      raise error if !error.nil?
      raise 'no response'
    end
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['200'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Crystalline::Array.new(Models::Shared::BLSOccupation))
      response = Models::Operations::GetV1SalaryEstimatesOccupationsResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        bls_occupations: T.unsafe(obj)
      )

      return response
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['422'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::UnprocessableEntityError)
      raise obj
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  else
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown status code received'

  end
end

#post_v1_employees_employee_id_salary_estimates(request_body:, employee_id:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil) ⇒ Object

Raises:

  • (StandardError)


45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/gusto_embedded/salary_estimates.rb', line 45

def post_v1_employees_employee_id_salary_estimates(request_body:, employee_id:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil)
  # post_v1_employees_employee_id_salary_estimates - Create a salary estimate for an employee
  # Create a salary estimate for an employee. This endpoint helps calculate a reasonable salary for S Corp owners based on their occupation, experience level, location, and business revenue.
  #
  # A salary estimate must include:
  # - Annual net revenue of the business
  # - ZIP code for location-based salary data
  # - One or more occupations with experience levels and time percentages (must sum to 100%)
  #
  # Only one in-progress salary estimate can exist per employee at a time. If an in-progress estimate already exists, you must either accept it or use the update endpoint.
  #
  # scope: `salary_estimates:write`
  #
  # If set, this operation will use `company_access_auth` from the global security.
  request = Models::Operations::PostV1EmployeesEmployeeIdSalaryEstimatesRequest.new(
    employee_id: employee_id,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    Models::Operations::PostV1EmployeesEmployeeIdSalaryEstimatesRequest,
    base_url,
    '/v1/employees/{employee_id}/salary_estimates',
    request
  )
  headers = Utils.get_headers(request)
  headers = T.cast(headers, T::Hash[String, String])
  req_content_type, data, form = Utils.serialize_request_body(request, false, false, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?

  if form && !form.empty?
    body = Utils.encode_form(form)
  elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
    body = URI.encode_www_form(T.cast(data, T::Hash[Symbol, Object]))
  else
    body = data
  end
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'post-v1-employees-employee_id-salary_estimates',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).post(url) do |req|
      req.body = body
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      Utils.configure_request_security(req, security, %i[company_access_auth])
      http_headers&.each do |key, value|
        req.headers[key.to_s] = value
      end

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    if http_response.nil? || Utils.error_status?(http_response.status)
      http_response = @sdk_configuration.hooks.after_error(
        error: error,
        hook_ctx: SDKHooks::AfterErrorHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    else
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    end
    
    if http_response.nil?
      raise error if !error.nil?
      raise 'no response'
    end
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['201'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Shared::SalaryEstimate)
      response = Models::Operations::PostV1EmployeesEmployeeIdSalaryEstimatesResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        salary_estimate: T.unsafe(obj)
      )

      return response
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['404'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::NotFoundErrorObject)
      raise obj
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['422'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::UnprocessableEntityError)
      raise obj
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  else
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown status code received'

  end
end

#post_v1_salary_estimates_uuid_accept(request_body:, uuid:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil) ⇒ Object

Raises:

  • (StandardError)


510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'lib/gusto_embedded/salary_estimates.rb', line 510

def post_v1_salary_estimates_uuid_accept(request_body:, uuid:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil)
  # post_v1_salary_estimates_uuid_accept - Accept a salary estimate
  # Accept and finalize a salary estimate. This associates the estimate with an employee job and marks it as accepted.
  #
  # Once accepted, the salary estimate becomes read-only for record-keeping purposes. The accepted salary can then be used to set up compensation for the employee.
  #
  # scope: `salary_estimates:write`
  #
  # If set, this operation will use `company_access_auth` from the global security.
  request = Models::Operations::PostV1SalaryEstimatesUuidAcceptRequest.new(
    uuid: uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    Models::Operations::PostV1SalaryEstimatesUuidAcceptRequest,
    base_url,
    '/v1/salary_estimates/{uuid}/accept',
    request
  )
  headers = Utils.get_headers(request)
  headers = T.cast(headers, T::Hash[String, String])
  req_content_type, data, form = Utils.serialize_request_body(request, false, false, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?

  if form && !form.empty?
    body = Utils.encode_form(form)
  elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
    body = URI.encode_www_form(T.cast(data, T::Hash[Symbol, Object]))
  else
    body = data
  end
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'post-v1-salary_estimates-uuid-accept',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).post(url) do |req|
      req.body = body
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      Utils.configure_request_security(req, security, %i[company_access_auth])
      http_headers&.each do |key, value|
        req.headers[key.to_s] = value
      end

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    if http_response.nil? || Utils.error_status?(http_response.status)
      http_response = @sdk_configuration.hooks.after_error(
        error: error,
        hook_ctx: SDKHooks::AfterErrorHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    else
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    end
    
    if http_response.nil?
      raise error if !error.nil?
      raise 'no response'
    end
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['200'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Shared::SalaryEstimate)
      response = Models::Operations::PostV1SalaryEstimatesUuidAcceptResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        salary_estimate: T.unsafe(obj)
      )

      return response
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['404'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::NotFoundErrorObject)
      raise obj
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['422'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::UnprocessableEntityError)
      raise obj
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  else
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown status code received'

  end
end

#put_v1_salary_estimates_id(request_body:, uuid:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil) ⇒ Object

Raises:

  • (StandardError)


347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/gusto_embedded/salary_estimates.rb', line 347

def put_v1_salary_estimates_id(request_body:, uuid:, x_gusto_api_version: nil, timeout_ms: nil, http_headers: nil)
  # put_v1_salary_estimates_id - Update a salary estimate
  # Update an existing salary estimate. You can modify the annual net revenue, ZIP code, and occupations.
  #
  # The salary estimate must not be finalized (accepted). Once accepted, salary estimates become read-only for record-keeping purposes.
  #
  # scope: `salary_estimates:write`
  #
  # If set, this operation will use `company_access_auth` from the global security.
  request = Models::Operations::PutV1SalaryEstimatesIdRequest.new(
    uuid: uuid,
    request_body: request_body,
    x_gusto_api_version: x_gusto_api_version
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    Models::Operations::PutV1SalaryEstimatesIdRequest,
    base_url,
    '/v1/salary_estimates/{uuid}',
    request
  )
  headers = Utils.get_headers(request)
  headers = T.cast(headers, T::Hash[String, String])
  req_content_type, data, form = Utils.serialize_request_body(request, false, false, :request_body, :json)
  headers['content-type'] = req_content_type
  raise StandardError, 'request body is required' if data.nil? && form.nil?

  if form && !form.empty?
    body = Utils.encode_form(form)
  elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
    body = URI.encode_www_form(T.cast(data, T::Hash[Symbol, Object]))
  else
    body = data
  end
  headers['Accept'] = 'application/json'
  headers['user-agent'] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'put-v1-salary_estimates-id',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).put(url) do |req|
      req.body = body
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      Utils.configure_request_security(req, security, %i[company_access_auth])
      http_headers&.each do |key, value|
        req.headers[key.to_s] = value
      end

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    if http_response.nil? || Utils.error_status?(http_response.status)
      http_response = @sdk_configuration.hooks.after_error(
        error: error,
        hook_ctx: SDKHooks::AfterErrorHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    else
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
    end
    
    if http_response.nil?
      raise error if !error.nil?
      raise 'no response'
    end
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['200'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Shared::SalaryEstimate)
      response = Models::Operations::PutV1SalaryEstimatesIdResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        salary_estimate: T.unsafe(obj)
      )

      return response
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['404'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::NotFoundErrorObject)
      raise obj
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['422'])
    if Utils.match_content_type(content_type, 'application/json')
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::UnprocessableEntityError)
      raise obj
    else
      raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  else
    raise ::GustoEmbedded::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown status code received'

  end
end