Class: GustoEmbedded::Shared::ContractorPaymentMethodSplitBy

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/gusto_embedded/models/shared/contractor_payment_method_split_by.rb

Overview

ContractorPaymentMethodSplitBy - Describes how the payment will be split. If split_by is Percentage, then the split amounts must add up to exactly 100. If split_by is Amount, then the last split amount must be nil to capture the remainder.