Class: GustoEmbedded::EarningTypes
- Inherits:
-
Object
- Object
- GustoEmbedded::EarningTypes
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/earningtypes.rb
Instance Method Summary collapse
- #create(company_id, request_body, x_gusto_api_version = nil) ⇒ Object
- #delete(company_id, earning_type_uuid, x_gusto_api_version = nil) ⇒ Object
-
#initialize(sdk_config) ⇒ EarningTypes
constructor
A new instance of EarningTypes.
- #list(company_id, x_gusto_api_version = nil) ⇒ Object
- #update(company_id, earning_type_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ EarningTypes
Returns a new instance of EarningTypes.
17 18 19 |
# File 'lib/gusto_embedded/earningtypes.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#create(company_id, request_body, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/gusto_embedded/earningtypes.rb', line 23 def create(company_id, request_body, x_gusto_api_version = nil) # create - Create a custom earning type # Create a custom earning type. # # If an inactive earning type exists with the same name, this will reactivate it instead of creating a new one. # # scope: `payrolls:write` request = ::GustoEmbedded::Operations::PostV1CompaniesCompanyIdEarningTypesRequest.new( company_id: company_id, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PostV1CompaniesCompanyIdEarningTypesRequest, base_url, '/v1/companies/{company_id}/earning_types', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.post(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PostV1CompaniesCompanyIdEarningTypesResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 201 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::EarningType) res.earning_type = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |
#delete(company_id, earning_type_uuid, x_gusto_api_version = nil) ⇒ Object
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/gusto_embedded/earningtypes.rb', line 202 def delete(company_id, earning_type_uuid, x_gusto_api_version = nil) # delete - Deactivate an earning type # Deactivate an earning type. # # scope: `payrolls:write` request = ::GustoEmbedded::Operations::DeleteV1CompaniesCompanyIdEarningTypesEarningTypeUuidRequest.new( company_id: company_id, earning_type_uuid: earning_type_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::DeleteV1CompaniesCompanyIdEarningTypesEarningTypeUuidRequest, base_url, '/v1/companies/{company_id}/earning_types/{earning_type_uuid}', request ) headers = Utils.get_headers(request) headers['Accept'] = '*/*' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.delete(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::DeleteV1CompaniesCompanyIdEarningTypesEarningTypeUuidResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 204 elsif r.status == 404 end res end |
#list(company_id, x_gusto_api_version = nil) ⇒ Object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/gusto_embedded/earningtypes.rb', line 87 def list(company_id, x_gusto_api_version = nil) # list - Get all earning types for a company # A payroll item in Gusto is associated to an earning type to name the type of earning described by the payroll item. # # #### Default Earning Type # Certain earning types are special because they have tax considerations. Those earning types are mostly the same for every company depending on its legal structure (LLC, Corporation, etc.) # # #### Custom Earning Type # Custom earning types are all the other earning types added specifically for a company. # # scope: `payrolls:read` request = ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdEarningTypesRequest.new( company_id: company_id, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdEarningTypesRequest, base_url, '/v1/companies/{company_id}/earning_types', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdEarningTypesResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::EarningTypeList) res.earning_type_list = out end elsif r.status == 404 end res end |
#update(company_id, earning_type_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/gusto_embedded/earningtypes.rb', line 139 def update(company_id, earning_type_uuid, request_body, x_gusto_api_version = nil) # update - Update an earning type # Update an earning type. # # scope: `payrolls:write` request = ::GustoEmbedded::Operations::PutV1CompaniesCompanyIdEarningTypesEarningTypeUuidRequest.new( company_id: company_id, earning_type_uuid: earning_type_uuid, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1CompaniesCompanyIdEarningTypesEarningTypeUuidRequest, base_url, '/v1/companies/{company_id}/earning_types/{earning_type_uuid}', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1CompaniesCompanyIdEarningTypesEarningTypeUuidResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::EarningType) res.earning_type = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |