Class: GustoEmbedded::EmployeeForms
- Inherits:
-
Object
- Object
- GustoEmbedded::EmployeeForms
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/employeeforms.rb
Instance Method Summary collapse
- #generate_w2(request_body, x_gusto_api_version = nil) ⇒ Object
- #get(employee_id, form_id, x_gusto_api_version = nil) ⇒ Object
- #get_pdf(employee_id, form_id, x_gusto_api_version = nil) ⇒ Object
-
#initialize(sdk_config) ⇒ EmployeeForms
constructor
A new instance of EmployeeForms.
- #list(employee_id, x_gusto_api_version = nil) ⇒ Object
- #sign(request) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ EmployeeForms
Returns a new instance of EmployeeForms.
17 18 19 |
# File 'lib/gusto_embedded/employeeforms.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#generate_w2(request_body, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/gusto_embedded/employeeforms.rb', line 23 def generate_w2(request_body, x_gusto_api_version = nil) # generate_w2 - Generate a W2 form [DEMO] # > 🚧 Demo action # > # > This action is only available in the Demo environment # # Generates a W2 document for testing purposes. # # scope: `employees:write` request = ::GustoEmbedded::Operations::PostV1SandboxGenerateW2Request.new( request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = "#{base_url}/v1/sandbox/generate_w2" headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.post(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PostV1SandboxGenerateW2Response.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Operations::PostV1SandboxGenerateW2Form) res.form = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |
#get(employee_id, form_id, x_gusto_api_version = nil) ⇒ Object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/gusto_embedded/employeeforms.rb', line 129 def get(employee_id, form_id, x_gusto_api_version = nil) # get - Get an employee form # Get an employee form # # scope: `employee_forms:read` request = ::GustoEmbedded::Operations::GetV1EmployeeFormRequest.new( employee_id: employee_id, form_id: form_id, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1EmployeeFormRequest, base_url, '/v1/employees/{employee_id}/forms/{form_id}', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1EmployeeFormResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Form) res.form = out end elsif r.status == 404 end res end |
#get_pdf(employee_id, form_id, x_gusto_api_version = nil) ⇒ Object
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/gusto_embedded/employeeforms.rb', line 176 def get_pdf(employee_id, form_id, x_gusto_api_version = nil) # get_pdf - Get the employee form pdf # Get the link to the employee form PDF # # scope: `employee_forms:read` request = ::GustoEmbedded::Operations::GetV1EmployeeFormPdfRequest.new( employee_id: employee_id, form_id: form_id, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1EmployeeFormPdfRequest, base_url, '/v1/employees/{employee_id}/forms/{form_id}/pdf', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1EmployeeFormPdfResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::FormPdf) res.form_pdf = out end elsif r.status == 404 end res end |
#list(employee_id, x_gusto_api_version = nil) ⇒ Object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/gusto_embedded/employeeforms.rb', line 83 def list(employee_id, x_gusto_api_version = nil) # list - Get all employee forms # Get a list of all employee's forms # # scope: `employee_forms:read` request = ::GustoEmbedded::Operations::GetV1EmployeeFormsRequest.new( employee_id: employee_id, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1EmployeeFormsRequest, base_url, '/v1/employees/{employee_id}/forms', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1EmployeeFormsResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::Form]) res.form_list = out end elsif r.status == 404 end res end |
#sign(request) ⇒ Object
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/gusto_embedded/employeeforms.rb', line 223 def sign(request) # sign - Sign an employee form # Sign an employee form. # # The optional preparer attributes are only valid for I-9 form. When a preparer is used, the # first name, last name, street address, city, state, and zip for that preparer are all required. # # scope: `employee_forms:sign` url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1EmployeeFormSignRequest, base_url, '/v1/employees/{employee_id}/forms/{form_id}/sign', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1EmployeeFormSignResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Form) res.form = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |