Class: GustoEmbedded::EmployeePaymentMethod
- Inherits:
-
Object
- Object
- GustoEmbedded::EmployeePaymentMethod
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/employeepaymentmethod.rb
Instance Method Summary collapse
- #create(employee_id, request_body, x_gusto_api_version = nil) ⇒ Object
- #delete_bank_account(employee_id, bank_account_uuid, x_gusto_api_version = nil) ⇒ Object
- #get(employee_id, x_gusto_api_version = nil) ⇒ Object
-
#initialize(sdk_config) ⇒ EmployeePaymentMethod
constructor
A new instance of EmployeePaymentMethod.
- #update(employee_id, request_body, x_gusto_api_version = nil) ⇒ Object
- #update_bank_account(employee_id, bank_account_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ EmployeePaymentMethod
Returns a new instance of EmployeePaymentMethod.
17 18 19 |
# File 'lib/gusto_embedded/employeepaymentmethod.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#create(employee_id, request_body, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/gusto_embedded/employeepaymentmethod.rb', line 23 def create(employee_id, request_body, x_gusto_api_version = nil) # create - Create an employee bank account # Creates an employee bank account. An employee can have multiple # bank accounts. Note that creating an employee bank account will also update # the employee's payment method. # # scope: `employee_payment_methods:write` request = ::GustoEmbedded::Operations::PostV1EmployeesEmployeeIdBankAccountsRequest.new( employee_id: employee_id, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PostV1EmployeesEmployeeIdBankAccountsRequest, base_url, '/v1/employees/{employee_id}/bank_accounts', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.post(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PostV1EmployeesEmployeeIdBankAccountsResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 201 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::EmployeeBankAccount) res.employee_bank_account = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |
#delete_bank_account(employee_id, bank_account_uuid, x_gusto_api_version = nil) ⇒ Object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/gusto_embedded/employeepaymentmethod.rb', line 87 def delete_bank_account(employee_id, bank_account_uuid, x_gusto_api_version = nil) # delete_bank_account - Delete an employee bank account # Deletes an employee bank account. To update an employee's bank # account details, delete the bank account first and create a new one. # # scope: `employee_payment_methods:write` request = ::GustoEmbedded::Operations::DeleteV1EmployeesEmployeeIdBankAccountsBankAccountIdRequest.new( employee_id: employee_id, bank_account_uuid: bank_account_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::DeleteV1EmployeesEmployeeIdBankAccountsBankAccountIdRequest, base_url, '/v1/employees/{employee_id}/bank_accounts/{bank_account_uuid}', request ) headers = Utils.get_headers(request) headers['Accept'] = '*/*' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.delete(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::DeleteV1EmployeesEmployeeIdBankAccountsBankAccountIdResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 204 elsif r.status == 404 end res end |
#get(employee_id, x_gusto_api_version = nil) ⇒ Object
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/gusto_embedded/employeepaymentmethod.rb', line 194 def get(employee_id, x_gusto_api_version = nil) # get - Get an employee's payment method # Fetches an employee's payment method. An employee payment method # describes how the payment should be split across the employee's associated # bank accounts. # # scope: `employee_payment_methods:read` request = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdPaymentMethodRequest.new( employee_id: employee_id, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdPaymentMethodRequest, base_url, '/v1/employees/{employee_id}/payment_method', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdPaymentMethodResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::EmployeePaymentMethod) res.employee_payment_method = out end elsif r.status == 404 end res end |
#update(employee_id, request_body, x_gusto_api_version = nil) ⇒ Object
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/gusto_embedded/employeepaymentmethod.rb', line 242 def update(employee_id, request_body, x_gusto_api_version = nil) # update - Update an employee's payment method # Updates an employee's payment method. Note that creating an employee # bank account will also update the employee's payment method. # # scope: `employee_payment_methods:write` request = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdPaymentMethodRequest.new( employee_id: employee_id, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdPaymentMethodRequest, base_url, '/v1/employees/{employee_id}/payment_method', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdPaymentMethodResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::EmployeePaymentMethod) res.employee_payment_method = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |
#update_bank_account(employee_id, bank_account_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/gusto_embedded/employeepaymentmethod.rb', line 131 def update_bank_account(employee_id, bank_account_uuid, request_body, x_gusto_api_version = nil) # update_bank_account - Update an employee bank account # Updates an employee bank account. # # scope: `employee_payment_methods:write` request = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdBankAccountsRequest.new( employee_id: employee_id, bank_account_uuid: bank_account_uuid, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdBankAccountsRequest, base_url, '/v1/employees/{employee_id}/bank_accounts/{bank_account_uuid}', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdBankAccountsResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::EmployeeBankAccount) res.employee_bank_account = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |