Class: GustoEmbedded::EmployeeTaxSetup
- Inherits:
-
Object
- Object
- GustoEmbedded::EmployeeTaxSetup
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/employeetaxsetup.rb
Instance Method Summary collapse
- #get_federal_taxes(employee_uuid, x_gusto_api_version = nil) ⇒ Object
- #get_state_taxes(employee_uuid, x_gusto_api_version = nil) ⇒ Object
-
#initialize(sdk_config) ⇒ EmployeeTaxSetup
constructor
A new instance of EmployeeTaxSetup.
- #update_federal_taxes(employee_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
- #update_state_taxes(employee_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ EmployeeTaxSetup
Returns a new instance of EmployeeTaxSetup.
17 18 19 |
# File 'lib/gusto_embedded/employeetaxsetup.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#get_federal_taxes(employee_uuid, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/gusto_embedded/employeetaxsetup.rb', line 23 def get_federal_taxes(employee_uuid, x_gusto_api_version = nil) # get_federal_taxes - Get an employee's federal taxes # Get attributes relevant for an employee's federal taxes. # # scope: `employee_federal_taxes:read` request = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdFederalTaxesRequest.new( employee_uuid: employee_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdFederalTaxesRequest, base_url, '/v1/employees/{employee_uuid}/federal_taxes', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdFederalTaxesResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::EmployeeFederalTax) res.employee_federal_tax = out end elsif r.status == 404 end res end |
#get_state_taxes(employee_uuid, x_gusto_api_version = nil) ⇒ Object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/gusto_embedded/employeetaxsetup.rb', line 131 def get_state_taxes(employee_uuid, x_gusto_api_version = nil) # get_state_taxes - Get an employee's state taxes # Get attributes relevant for an employee's state taxes. # # The data required to correctly calculate an employee's state taxes varies by both home and work location. This API returns information about each question that must be answered grouped by state. Mostly commonly, an employee lives and works in the same state and will only have questions for a single state. The response contains metadata about each question, the type of answer expected, and the current answer stored in Gusto for that question. # # Answers are represented by an array. Today, this array can only be empty or contain exactly one element, but is designed to allow for forward compatibility with effective-dated fields. Until effective dated answers are supported, the `valid_from` and `valid_up_to` must always be `"2010-01-01"` and `null` respectively. # # ## About filing new hire reports # Payroll Admins are responsible for filing a new hire report for each Employee. The `file_new_hire_report` question will only be listed if: # - the `employee.onboarding_status` is one of the following: # - `admin_onboarding_incomplete` # - `self_onboarding_awaiting_admin_review` # - that employee's work state requires filing a new hire report # # scope: `employee_state_taxes:read` # request = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdStateTaxesRequest.new( employee_uuid: employee_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdStateTaxesRequest, base_url, '/v1/employees/{employee_uuid}/state_taxes', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1EmployeesEmployeeIdStateTaxesResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::EmployeeStateTax]) res.employee_state_taxes_list = out end elsif r.status == 404 end res end |
#update_federal_taxes(employee_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/gusto_embedded/employeetaxsetup.rb', line 69 def update_federal_taxes(employee_uuid, request_body, x_gusto_api_version = nil) # update_federal_taxes - Update an employee's federal taxes # Update attributes relevant for an employee's federal taxes. # # scope: `employee_federal_taxes:write` request = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdFederalTaxesRequest.new( employee_uuid: employee_uuid, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdFederalTaxesRequest, base_url, '/v1/employees/{employee_uuid}/federal_taxes', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdFederalTaxesResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::EmployeeFederalTax) res.employee_federal_tax = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |
#update_state_taxes(employee_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/gusto_embedded/employeetaxsetup.rb', line 189 def update_state_taxes(employee_uuid, request_body, x_gusto_api_version = nil) # update_state_taxes - Update an employee's state taxes # Update attributes relevant for an employee's state taxes. # # As described for the GET endpoint, the answers must be supplied in the effective-dated format, but currently only a single answer will be accepted - `valid_from` and `valid_up_to` must be `"2010-01-01"` and `null` respectively. # # scope: `employee_state_taxes:write` request = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdStateTaxesRequest.new( employee_uuid: employee_uuid, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdStateTaxesRequest, base_url, '/v1/employees/{employee_uuid}/state_taxes', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1EmployeesEmployeeIdStateTaxesResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::EmployeeStateTax]) res.employee_state_taxes_list = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Operations::ResponseBody]) res.response_bodies = out end end res end |