Class: GustoEmbedded::Events
- Inherits:
-
Object
- Object
- GustoEmbedded::Events
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/events.rb
Instance Method Summary collapse
- #get(request, security) ⇒ Object
-
#initialize(sdk_config) ⇒ Events
constructor
A new instance of Events.
Constructor Details
#initialize(sdk_config) ⇒ Events
Returns a new instance of Events.
17 18 19 |
# File 'lib/gusto_embedded/events.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#get(request, security) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/gusto_embedded/events.rb', line 23 def get(request, security) # get - Get all events # Fetch all events, going back up to 30 days, that your partner application has the required scopes for. Note that a partner does NOT have to have verified webhook subscriptions in order to utilize this endpoint. # # > 📘 System Access Authentication # > # > This endpoint uses the [Bearer Auth scheme with the system-level access token in the HTTP Authorization header](https://docs.gusto.com/embedded-payroll/docs/system-access). # # scope: `events:read` url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = "#{base_url}/v1/events" headers = Utils.get_headers(request) query_params = Utils.get_query_params(::GustoEmbedded::Operations::GetEventsRequest, request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers req.params = query_params Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetEventsResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::Event]) res.event_list = out end end res end |