Class: GustoEmbedded::HistoricalEmployees
- Inherits:
-
Object
- Object
- GustoEmbedded::HistoricalEmployees
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/historicalemployees.rb
Instance Method Summary collapse
-
#initialize(sdk_config) ⇒ HistoricalEmployees
constructor
A new instance of HistoricalEmployees.
- #update(company_uuid, historical_employee_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ HistoricalEmployees
Returns a new instance of HistoricalEmployees.
17 18 19 |
# File 'lib/gusto_embedded/historicalemployees.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#update(company_uuid, historical_employee_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/gusto_embedded/historicalemployees.rb', line 23 def update(company_uuid, historical_employee_uuid, request_body, x_gusto_api_version = nil) # update - Update a historical employee # Update a historical employee, an employee that was previously dismissed from the company in the current year. # # scope: `employees:manage` request = ::GustoEmbedded::Operations::PutV1HistoricalEmployeesRequest.new( company_uuid: company_uuid, historical_employee_uuid: historical_employee_uuid, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1HistoricalEmployeesRequest, base_url, '/v1/companies/{company_uuid}/historical_employees/{historical_employee_uuid}', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1HistoricalEmployeesResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Employee) res.employee = out end elsif r.status == 404 end res end |