Class: GustoEmbedded::Locations
- Inherits:
-
Object
- Object
- GustoEmbedded::Locations
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/locations.rb
Instance Method Summary collapse
- #create(company_id, request_body, x_gusto_api_version = nil) ⇒ Object
- #get(company_id, page = nil, per = nil, x_gusto_api_version = nil) ⇒ Object
- #get_minimum_wages(location_uuid, effective_date = nil, x_gusto_api_version = nil) ⇒ Object
-
#initialize(sdk_config) ⇒ Locations
constructor
A new instance of Locations.
- #retrieve(location_id, x_gusto_api_version = nil) ⇒ Object
- #update(location_id, request_body, x_gusto_api_version = nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ Locations
Returns a new instance of Locations.
17 18 19 |
# File 'lib/gusto_embedded/locations.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#create(company_id, request_body, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/gusto_embedded/locations.rb', line 23 def create(company_id, request_body, x_gusto_api_version = nil) # create - Create a company location # Company locations represent all addresses associated with a company. These can be filing addresses, mailing addresses, and/or work locations; one address may serve multiple, or all, purposes. # # Since all company locations are subsets of locations, retrieving or updating an individual record should be done via the locations endpoints. # # scope: `companies:write` request = ::GustoEmbedded::Operations::PostV1CompaniesCompanyIdLocationsRequest.new( company_id: company_id, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PostV1CompaniesCompanyIdLocationsRequest, base_url, '/v1/companies/{company_id}/locations', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.post(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PostV1CompaniesCompanyIdLocationsResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 201 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Location) res.location = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |
#get(company_id, page = nil, per = nil, x_gusto_api_version = nil) ⇒ Object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/gusto_embedded/locations.rb', line 87 def get(company_id, page = nil, per = nil, x_gusto_api_version = nil) # get - Get company locations # Company locations represent all addresses associated with a company. These can be filing addresses, mailing addresses, and/or work locations; one address may serve multiple, or all, purposes. # # Since all company locations are subsets of locations, retrieving or updating an individual record should be done via the locations endpoints. # # scope: `companies:read` request = ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdLocationsRequest.new( company_id: company_id, page: page, per: per, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdLocationsRequest, base_url, '/v1/companies/{company_id}/locations', request ) headers = Utils.get_headers(request) query_params = Utils.get_query_params(::GustoEmbedded::Operations::GetV1CompaniesCompanyIdLocationsRequest, request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers req.params = query_params security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1CompaniesCompanyIdLocationsResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::Location]) res.location_list = out end elsif r.status == 404 end res end |
#get_minimum_wages(location_uuid, effective_date = nil, x_gusto_api_version = nil) ⇒ Object
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/gusto_embedded/locations.rb', line 247 def get_minimum_wages(location_uuid, effective_date = nil, x_gusto_api_version = nil) # get_minimum_wages - Get minimum wages for a location # Get minimum wages for a location # # scope: `companies:read` request = ::GustoEmbedded::Operations::GetV1LocationsLocationUuidMinimumWagesRequest.new( location_uuid: location_uuid, effective_date: effective_date, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1LocationsLocationUuidMinimumWagesRequest, base_url, '/v1/locations/{location_uuid}/minimum_wages', request ) headers = Utils.get_headers(request) query_params = Utils.get_query_params(::GustoEmbedded::Operations::GetV1LocationsLocationUuidMinimumWagesRequest, request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers req.params = query_params security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1LocationsLocationUuidMinimumWagesResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::MinimumWage]) res.minimum_wage_list = out end elsif r.status == 404 end res end |
#retrieve(location_id, x_gusto_api_version = nil) ⇒ Object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/gusto_embedded/locations.rb', line 139 def retrieve(location_id, x_gusto_api_version = nil) # retrieve - Get a location # Get a location. # # scope: `companies:read` request = ::GustoEmbedded::Operations::GetV1LocationsLocationIdRequest.new( location_id: location_id, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1LocationsLocationIdRequest, base_url, '/v1/locations/{location_id}', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1LocationsLocationIdResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Location) res.location = out end elsif r.status == 404 end res end |
#update(location_id, request_body, x_gusto_api_version = nil) ⇒ Object
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/gusto_embedded/locations.rb', line 185 def update(location_id, request_body, x_gusto_api_version = nil) # update - Update a location # Update a location. # # scope: `companies.write` request = ::GustoEmbedded::Operations::PutV1LocationsLocationIdRequest.new( location_id: location_id, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1LocationsLocationIdRequest, base_url, '/v1/locations/{location_id}', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1LocationsLocationIdResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Location) res.location = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |