Class: GustoEmbedded::Models::Operations::Reason
- Inherits:
-
T::Enum
- Object
- T::Enum
- GustoEmbedded::Models::Operations::Reason
- Defined in:
- lib/gusto_embedded/models/operations/reason.rb
Overview
Reason - Explanation for why the company is suspending their account.
> 🚧 FEIN or entity type changes require Customer Support > If a company is switching FEIN or changing their entity type, this change must be performed by Gusto Customer Support and cannot be performed via the API at this time.