Class: GustoEmbedded::Models::Shared::PayScheduleCreateRequest
- Inherits:
-
Object
- Object
- GustoEmbedded::Models::Shared::PayScheduleCreateRequest
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/gusto_embedded/models/shared/pay_schedule_create_request.rb
Overview
Request body for creating a pay schedule. Required when a company has no pay schedules (onboarding) or when adding an additional schedule. Be sure to [check state laws](www.dol.gov/agencies/whd/state/payday) to know what schedule is right for your customers.
-
anchor_pay_date: The first date that employees on this pay schedule will be paid (first company payday).
-
anchor_end_of_pay_period: The last date of the first pay period; can be the same as anchor_pay_date.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(frequency:, anchor_pay_date:, anchor_end_of_pay_period:, day_1: nil, day_2: nil, custom_name: nil) ⇒ PayScheduleCreateRequest
constructor
A new instance of PayScheduleCreateRequest.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(frequency:, anchor_pay_date:, anchor_end_of_pay_period:, day_1: nil, day_2: nil, custom_name: nil) ⇒ PayScheduleCreateRequest
Returns a new instance of PayScheduleCreateRequest.
42 43 44 45 46 47 48 49 |
# File 'lib/gusto_embedded/models/shared/pay_schedule_create_request.rb', line 42 def initialize(frequency:, anchor_pay_date:, anchor_end_of_pay_period:, day_1: nil, day_2: nil, custom_name: nil) @frequency = frequency @anchor_pay_date = anchor_pay_date @anchor_end_of_pay_period = anchor_end_of_pay_period @day_1 = day_1 @day_2 = day_2 @custom_name = custom_name end |
Instance Method Details
#==(other) ⇒ Object
52 53 54 55 56 57 58 59 60 61 |
# File 'lib/gusto_embedded/models/shared/pay_schedule_create_request.rb', line 52 def ==(other) return false unless other.is_a? self.class return false unless @frequency == other.frequency return false unless @anchor_pay_date == other.anchor_pay_date return false unless @anchor_end_of_pay_period == other.anchor_end_of_pay_period return false unless @day_1 == other.day_1 return false unless @day_2 == other.day_2 return false unless @custom_name == other.custom_name true end |