Class: GustoEmbedded::Notifications
- Inherits:
-
Object
- Object
- GustoEmbedded::Notifications
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/notifications.rb
Instance Method Summary collapse
- #get_details(notification_uuid, x_gusto_api_version = nil) ⇒ Object
-
#initialize(sdk_config) ⇒ Notifications
constructor
A new instance of Notifications.
Constructor Details
#initialize(sdk_config) ⇒ Notifications
Returns a new instance of Notifications.
17 18 19 |
# File 'lib/gusto_embedded/notifications.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#get_details(notification_uuid, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/gusto_embedded/notifications.rb', line 23 def get_details(notification_uuid, x_gusto_api_version = nil) # get_details - Get a notification's details # Upon receiving a notification webhook event, use this endpoint to fetch the notification's details. The notification details include basic suggested content that can help you build notifications in your platform. # # Note: partners are responsible for the delivery and any custom state management of notifications in their application. Refer to our [partner notification guide](https://docs.gusto.com/embedded-payroll/docs/partner-notifications) for more details. # # If the notification UUID is not found, the response will be 404 Not Found. If the notification's supporting data is no longer valid, the response will be 422 Unprocessable Entity. # # scope: `notifications:read` request = ::GustoEmbedded::Operations::GetNotificationsNotificationUuidRequest.new( notification_uuid: notification_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetNotificationsNotificationUuidRequest, base_url, '/v1/notifications/{notification_uuid}', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetNotificationsNotificationUuidResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Notification) res.notification = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |