Class: GustoEmbedded::Operations::PostV1EmployeesEmployeeIdEmployeeBenefitsType
- Inherits:
-
T::Enum
- Object
- T::Enum
- GustoEmbedded::Operations::PostV1EmployeesEmployeeIdEmployeeBenefitsType
- Defined in:
- lib/gusto_embedded/models/operations/post_v1_employees_employee_id_employee_benefits_type.rb
Overview
PostV1EmployeesEmployeeIdEmployeeBenefitsType - The company contribution scheme.
‘amount`: The company contributes a fixed amount per payroll. If elective is true, the contribution is matching, dollar-for-dollar.
‘percentage`: The company contributes a percentage of the payroll amount per payroll period. If elective is true, the contribution is matching, dollar-for-dollar.
‘tiered`: The size of the company contribution corresponds to the size of the employee deduction relative to a tiered matching scheme.