Class: GustoEmbedded::Operations::SplitBy
- Inherits:
-
T::Enum
- Object
- T::Enum
- GustoEmbedded::Operations::SplitBy
- Defined in:
- lib/gusto_embedded/models/operations/split_by.rb
Overview
SplitBy - Describes how the payment will be split. If split_by is Percentage, then the split amounts must add up to exactly 100. If split_by is Amount, then the last split amount must be nil to capture the remainder.