Class: GustoEmbedded::Reports
- Inherits:
-
Object
- Object
- GustoEmbedded::Reports
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/reports.rb
Instance Method Summary collapse
- #create_custom(company_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
- #get(report_uuid, x_gusto_api_version = nil) ⇒ Object
- #get_template(company_uuid, report_type, x_gusto_api_version = nil) ⇒ Object
-
#initialize(sdk_config) ⇒ Reports
constructor
A new instance of Reports.
Constructor Details
#initialize(sdk_config) ⇒ Reports
Returns a new instance of Reports.
17 18 19 |
# File 'lib/gusto_embedded/reports.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#create_custom(company_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/gusto_embedded/reports.rb', line 23 def create_custom(company_uuid, request_body, x_gusto_api_version = nil) # create_custom - Create a custom report # Create a custom report for a company. This endpoint initiates creating a custom report with custom columns, groupings, and filters. The `request_uuid` in the response can then be used to poll for the status and report URL upon completion using the report GET endpoint. This URL is valid for 10 minutes. # # scope: `company_reports:write` request = ::GustoEmbedded::Operations::PostCompaniesCompanyUuidReportsRequest.new( company_uuid: company_uuid, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PostCompaniesCompanyUuidReportsRequest, base_url, '/v1/companies/{company_uuid}/reports', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.post(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PostCompaniesCompanyUuidReportsResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::CreateReport) res.create_report = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |
#get(report_uuid, x_gusto_api_version = nil) ⇒ Object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/gusto_embedded/reports.rb', line 85 def get(report_uuid, x_gusto_api_version = nil) # get - Get a report # Get a company's report given the `request_uuid`. The response will include the report request's status and, if complete, the report URL. # # scope: `company_reports:read` request = ::GustoEmbedded::Operations::GetReportsReportUuidRequest.new( report_uuid: report_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetReportsReportUuidRequest, base_url, '/v1/reports/{report_uuid}', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetReportsReportUuidResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::Report) res.report = out end elsif r.status == 404 end res end |
#get_template(company_uuid, report_type, x_gusto_api_version = nil) ⇒ Object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/gusto_embedded/reports.rb', line 131 def get_template(company_uuid, report_type, x_gusto_api_version = nil) # get_template - Get a report template # Get a company's report template. The only supported report type is `payroll_journal`. The resulting columns and groupings from this endpoint can be used as a guidance to create the report using the POST create report endpoint. # # scope: `company_reports:write` request = ::GustoEmbedded::Operations::GetCompaniesCompanyUuidReportTemplatesReportTypeRequest.new( company_uuid: company_uuid, report_type: report_type, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetCompaniesCompanyUuidReportTemplatesReportTypeRequest, base_url, '/v1/companies/{company_uuid}/report_templates/{report_type}', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers security = !@sdk_configuration.nil? && !@sdk_configuration.security_source.nil? ? @sdk_configuration.security_source.call : nil Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetCompaniesCompanyUuidReportTemplatesReportTypeResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::ReportTemplate) res.report_template = out end elsif r.status == 404 end res end |