Class: GustoEmbedded::Shared::Garnishment
- Inherits:
-
Crystalline::FieldAugmented
- Object
- Crystalline::FieldAugmented
- GustoEmbedded::Shared::Garnishment
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/models/shared/garnishment.rb
Overview
Garnishments, or employee deductions, are fixed amounts or percentages deducted from an employee’s pay. They can be deducted a specific number of times or on a recurring basis. Garnishments can also have maximum deductions on a yearly or per-pay-period bases. Common uses for garnishments are court-ordered payments for child support or back taxes. Some companies provide loans to their employees that are repaid via garnishments.
Instance Method Summary collapse
-
#initialize(uuid: nil, active: nil, amount: nil, annual_maximum: nil, child_support: nil, court_ordered: nil, deduct_as_percentage: nil, description: nil, employee_uuid: nil, garnishment_type: nil, pay_period_maximum: nil, recurring: nil, times: nil, total_amount: nil, version: nil) ⇒ Garnishment
constructor
A new instance of Garnishment.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(uuid: nil, active: nil, amount: nil, annual_maximum: nil, child_support: nil, court_ordered: nil, deduct_as_percentage: nil, description: nil, employee_uuid: nil, garnishment_type: nil, pay_period_maximum: nil, recurring: nil, times: nil, total_amount: nil, version: nil) ⇒ Garnishment
Returns a new instance of Garnishment.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/gusto_embedded/models/shared/garnishment.rb', line 47 def initialize(uuid: nil, active: nil, amount: nil, annual_maximum: nil, child_support: nil, court_ordered: nil, deduct_as_percentage: nil, description: nil, employee_uuid: nil, garnishment_type: nil, pay_period_maximum: nil, recurring: nil, times: nil, total_amount: nil, version: nil) @uuid = uuid @active = active @amount = amount @annual_maximum = annual_maximum @child_support = child_support @court_ordered = court_ordered @deduct_as_percentage = deduct_as_percentage @description = description @employee_uuid = employee_uuid @garnishment_type = garnishment_type @pay_period_maximum = pay_period_maximum @recurring = recurring @times = times @total_amount = total_amount @version = version end |