Class: GustoEmbedded::Shared::TaxRefunds
- Inherits:
-
Crystalline::FieldAugmented
- Object
- Crystalline::FieldAugmented
- GustoEmbedded::Shared::TaxRefunds
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/models/shared/tax_refunds.rb
Overview
Describes the taxes which are refundable to the company for this suspension. These may be refunded, or paid by Gusto, depending on the value in ‘reconcile_tax_method`.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil) ⇒ TaxRefunds
constructor
A new instance of TaxRefunds.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(amount: nil, description: nil) ⇒ TaxRefunds
Returns a new instance of TaxRefunds.
23 24 25 26 |
# File 'lib/gusto_embedded/models/shared/tax_refunds.rb', line 23 def initialize(amount: nil, description: nil) @amount = amount @description = description end |