Class: GustoEmbedded::Shared::VerificationStatus
- Inherits:
-
T::Enum
- Object
- T::Enum
- GustoEmbedded::Shared::VerificationStatus
- Defined in:
- lib/gusto_embedded/models/shared/verification_status.rb
Overview
VerificationStatus - The verification status of the bank account.
‘awaiting_deposits’ means the bank account is just created and money is being transferred. ‘ready_for_verification’ means the micro-deposits are completed and the verification process can begin by using the verify endpoint. ‘verified’ means the bank account is verified.