Class: GustoEmbedded::Webhooks
- Inherits:
-
Object
- Object
- GustoEmbedded::Webhooks
- Extended by:
- T::Sig
- Defined in:
- lib/gusto_embedded/webhooks.rb
Instance Method Summary collapse
- #create_subscription(security, request_body, x_gusto_api_version = nil) ⇒ Object
- #delete_subscription(security, webhook_subscription_uuid, x_gusto_api_version = nil) ⇒ Object
- #get_subscription(security, webhook_subscription_uuid, x_gusto_api_version = nil) ⇒ Object
-
#initialize(sdk_config) ⇒ Webhooks
constructor
A new instance of Webhooks.
- #list_subscriptions(security, x_gusto_api_version = nil) ⇒ Object
- #request_verification_token(security, webhook_subscription_uuid, x_gusto_api_version = nil) ⇒ Object
- #update_subscription(security, webhook_subscription_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
- #verify(security, webhook_subscription_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ Webhooks
Returns a new instance of Webhooks.
17 18 19 |
# File 'lib/gusto_embedded/webhooks.rb', line 17 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#create_subscription(security, request_body, x_gusto_api_version = nil) ⇒ Object
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/gusto_embedded/webhooks.rb', line 23 def create_subscription(security, request_body, x_gusto_api_version = nil) # create_subscription - Create a webhook subscription # Create a webhook subscription to receive events of the specified subscription_types whenever there is a state change. # # > 📘 System Access Authentication # > # > This endpoint uses the [Bearer Auth scheme with the system-level access token in the HTTP Authorization header](https://docs.gusto.com/embedded-payroll/docs/system-access). # # scope: `webhook_subscriptions:write` request = ::GustoEmbedded::Operations::PostV1WebhookSubscriptionRequest.new( request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = "#{base_url}/v1/webhook_subscriptions" headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.post(url) do |req| req.headers = headers Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PostV1WebhookSubscriptionResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 201 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::WebhookSubscription) res.webhook_subscription = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |
#delete_subscription(security, webhook_subscription_uuid, x_gusto_api_version = nil) ⇒ Object
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/gusto_embedded/webhooks.rb', line 241 def delete_subscription(security, webhook_subscription_uuid, x_gusto_api_version = nil) # delete_subscription - Delete a webhook subscription # Deletes the Webhook Subscription associated with the provided UUID. # # > 📘 System Access Authentication # > # > This endpoint uses the [Bearer Auth scheme with the system-level access token in the HTTP Authorization header](https://docs.gusto.com/embedded-payroll/docs/system-access). # # scope: `webhook_subscriptions:write` # request = ::GustoEmbedded::Operations::DeleteV1WebhookSubscriptionUuidRequest.new( webhook_subscription_uuid: webhook_subscription_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::DeleteV1WebhookSubscriptionUuidRequest, base_url, '/v1/webhook_subscriptions/{webhook_subscription_uuid}', request ) headers = Utils.get_headers(request) headers['Accept'] = '*/*' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.delete(url) do |req| req.headers = headers Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::DeleteV1WebhookSubscriptionUuidResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 204 elsif r.status == 404 end res end |
#get_subscription(security, webhook_subscription_uuid, x_gusto_api_version = nil) ⇒ Object
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/gusto_embedded/webhooks.rb', line 191 def get_subscription(security, webhook_subscription_uuid, x_gusto_api_version = nil) # get_subscription - Get a webhook subscription # Returns the Webhook Subscription associated with the provided UUID. # # > 📘 System Access Authentication # > # > This endpoint uses the [Bearer Auth scheme with the system-level access token in the HTTP Authorization header](https://docs.gusto.com/embedded-payroll/docs/system-access). # # scope: `webhook_subscriptions:read` # request = ::GustoEmbedded::Operations::GetV1WebhookSubscriptionUuidRequest.new( webhook_subscription_uuid: webhook_subscription_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1WebhookSubscriptionUuidRequest, base_url, '/v1/webhook_subscriptions/{webhook_subscription_uuid}', request ) headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1WebhookSubscriptionUuidResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::WebhookSubscription) res.webhook_subscription = out end elsif r.status == 404 end res end |
#list_subscriptions(security, x_gusto_api_version = nil) ⇒ Object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/gusto_embedded/webhooks.rb', line 82 def list_subscriptions(security, x_gusto_api_version = nil) # list_subscriptions - List webhook subscriptions # Returns all webhook subscriptions associated with the provided Partner API token. # # > 📘 System Access Authentication # > # > This endpoint uses the [Bearer Auth scheme with the system-level access token in the HTTP Authorization header](https://docs.gusto.com/embedded-payroll/docs/system-access). # # scope: `webhook_subscriptions:read` request = ::GustoEmbedded::Operations::GetV1WebhookSubscriptionsRequest.new( x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = "#{base_url}/v1/webhook_subscriptions" headers = Utils.get_headers(request) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1WebhookSubscriptionsResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), T::Array[::GustoEmbedded::Shared::WebhookSubscription]) res.webhook_subscriptions_list = out end elsif r.status == 404 end res end |
#request_verification_token(security, webhook_subscription_uuid, x_gusto_api_version = nil) ⇒ Object
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/gusto_embedded/webhooks.rb', line 355 def request_verification_token(security, webhook_subscription_uuid, x_gusto_api_version = nil) # request_verification_token - Request the webhook subscription verification_token # Request that the webhook subscription `verification_token` be POSTed to the Subscription URL. # # > 📘 System Access Authentication # > # > This endpoint uses the [Bearer Auth scheme with the system-level access token in the HTTP Authorization header](https://docs.gusto.com/embedded-payroll/docs/system-access). # # scope: `webhook_subscriptions:read` # request = ::GustoEmbedded::Operations::GetV1WebhookSubscriptionVerificationTokenUuidRequest.new( webhook_subscription_uuid: webhook_subscription_uuid, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::GetV1WebhookSubscriptionVerificationTokenUuidRequest, base_url, '/v1/webhook_subscriptions/{webhook_subscription_uuid}/request_verification_token', request ) headers = Utils.get_headers(request) headers['Accept'] = '*/*' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.get(url) do |req| req.headers = headers Utils.configure_request_security(req, security) if !security.nil? end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::GetV1WebhookSubscriptionVerificationTokenUuidResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 elsif r.status == 404 end res end |
#update_subscription(security, webhook_subscription_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/gusto_embedded/webhooks.rb', line 125 def update_subscription(security, webhook_subscription_uuid, request_body, x_gusto_api_version = nil) # update_subscription - Update a webhook subscription # Updates the Webhook Subscription associated with the provided UUID. # # > 📘 System Access Authentication # > # > This endpoint uses the [Bearer Auth scheme with the system-level access token in the HTTP Authorization header](https://docs.gusto.com/embedded-payroll/docs/system-access). # # scope: `webhook_subscriptions:write` # request = ::GustoEmbedded::Operations::PutV1WebhookSubscriptionUuidRequest.new( webhook_subscription_uuid: webhook_subscription_uuid, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1WebhookSubscriptionUuidRequest, base_url, '/v1/webhook_subscriptions/{webhook_subscription_uuid}', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1WebhookSubscriptionUuidResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::WebhookSubscription) res.webhook_subscription = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |
#verify(security, webhook_subscription_uuid, request_body, x_gusto_api_version = nil) ⇒ Object
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/gusto_embedded/webhooks.rb', line 287 def verify(security, webhook_subscription_uuid, request_body, x_gusto_api_version = nil) # verify - Verify the webhook subscription # When a webhook subscription is created, a `verification_token` is POSTed to the registered webhook subscription URL. This `verify` endpoint needs to be called with `verification_token` before webhook events can be sent to the registered webhook URL. # # Use the /v1/webhook_subscriptions/{webhook_subscription_uuid}/request_verification_token API to resend the `verification_token` to the Subscriber. # # > 📘 System Access Authentication # > # > This endpoint uses the [Bearer Auth scheme with the system-level access token in the HTTP Authorization header](https://docs.gusto.com/embedded-payroll/docs/system-access). # # scope: `webhook_subscriptions:write` # request = ::GustoEmbedded::Operations::PutV1VerifyWebhookSubscriptionUuidRequest.new( webhook_subscription_uuid: webhook_subscription_uuid, request_body: request_body, x_gusto_api_version: x_gusto_api_version ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( ::GustoEmbedded::Operations::PutV1VerifyWebhookSubscriptionUuidRequest, base_url, '/v1/webhook_subscriptions/{webhook_subscription_uuid}/verify', request ) headers = Utils.get_headers(request) req_content_type, data, form = Utils.serialize_request_body(request, :request_body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent r = @sdk_configuration.client.put(url) do |req| req.headers = headers Utils.configure_request_security(req, security) if !security.nil? if form req.body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') req.body = URI.encode_www_form(data) else req.body = data end end content_type = r.headers.fetch('Content-Type', 'application/octet-stream') res = ::GustoEmbedded::Operations::PutV1VerifyWebhookSubscriptionUuidResponse.new( status_code: r.status, content_type: content_type, raw_response: r ) if r.status == 200 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::WebhookSubscription) res.webhook_subscription = out end elsif r.status == 404 elsif r.status == 422 if Utils.match_content_type(content_type, 'application/json') out = Crystalline.unmarshal_json(JSON.parse(r.env.response_body), ::GustoEmbedded::Shared::UnprocessableEntityErrorObject) res.unprocessable_entity_error_object = out end end res end |